@@ -4,6 +4,7 @@
 
 import json
 import pickle
+import warnings
 from pathlib import Path
 from typing import Any, List, Union
 
@@ -113,8 +114,16 @@ def _load_attribute(
     file_format: str,
 ) -> Any:
     if file_format == SerializationFormats.PICKLE:
-        with open(path, 'rb') as f:
-            return pickle.load(f)
+        val = None
+        try:
+            with open(path, 'rb') as f:
+                val = pickle.load(f)
+        except Exception:
+            model_load_err = ('ERROR-LOADING-EXPLAINER: '
+                              'There was an error loading the explainer. '
+                              'Some of RAI dashboard features may not work.')
+            warnings.warn(model_load_err, UserWarning)
+        return val
     elif file_format == SerializationFormats.JSON:
         with open(path, 'r') as f:
             return json.load(f)
