@@ -14,8 +14,7 @@ from responsibleai._internal.constants import (CausalManagerKeys,
                                                ListProperties, ManagerNames)
 from responsibleai._tools.causal.causal_config import CausalConfig
 from responsibleai._tools.causal.causal_constants import (DefaultParams,
-                                                          ModelTypes,
-                                                          ResultAttributes)
+                                                          ModelTypes)
 from responsibleai._tools.causal.causal_result import CausalResult
 from responsibleai._tools.shared.state_directory_management import \
     DirectoryManager
@@ -228,7 +227,7 @@ class CausalManager(BaseManager):
 
     def _create_policy(
         self,
-        causal_analysis,
+        causal_result,
         X_test,
         treatment_feature,
         treatment_cost,
@@ -236,29 +235,14 @@ class CausalManager(BaseManager):
         max_tree_depth,
         min_tree_leaf_samples,
     ):
-        local_policies = causal_analysis.individualized_policy(
-            X_test, treatment_feature,
-            treatment_costs=treatment_cost,
-            alpha=alpha)
-
-        tree = causal_analysis._policy_tree_output(
-            X_test, treatment_feature,
-            treatment_costs=treatment_cost,
-            max_depth=max_tree_depth,
-            min_samples_leaf=min_tree_leaf_samples,
-            alpha=alpha)
-
-        return {
-            ResultAttributes.TREATMENT_FEATURE: treatment_feature,
-            ResultAttributes.CONTROL_TREATMENT: tree.control_name,
-            ResultAttributes.LOCAL_POLICIES: local_policies,
-            ResultAttributes.POLICY_GAINS: {
-                ResultAttributes.RECOMMENDED_POLICY_GAINS:
-                    tree.policy_value,
-                ResultAttributes.TREATMENT_GAINS: tree.always_treat,
-            },
-            ResultAttributes.POLICY_TREE: tree.tree_dictionary
-        }
+        return causal_result._create_policy(
+            X_test=X_test,
+            treatment_feature=treatment_feature,
+            treatment_cost=treatment_cost,
+            alpha=alpha,
+            max_tree_depth=max_tree_depth,
+            min_tree_leaf_samples=min_tree_leaf_samples,
+        )
 
     def _whatif(self, id, X, X_feature_new, feature_name, y, alpha=0.1):
         """Get what-if data."""
@@ -269,6 +253,76 @@ class CausalManager(BaseManager):
         return result._whatif(X, X_feature_new, feature_name,
                               y, alpha=alpha).to_dict(orient="records")
 
+    def request_global_cohort_effects(self, id, X_test):
+        """Get global causal effects for cohort data.
+
+        :param id: The query id for finding the
+                   causal config.
+        :type id: str
+        :param X_test: The data for which the global causal effects
+                       needs to be generated.
+        :type X_test: Any
+        :return: An object of type CausalData with
+                 causal effects.
+        :rtype: CausalData
+
+        """
+        filtered = [r for r in self.get() if r.id == id]
+        if len(filtered) == 0:
+            raise ValueError(f"Failed to find causal result with ID: {id}")
+        result = filtered[0]
+        return result._global_cohort_effects(X_test)
+
+    def request_local_instance_effects(self, id, X_test):
+        """Get local causal effects for a given data point.
+
+        :param id: The query id for finding the
+                   causal config.
+        :type id: str
+        :param X_test: The data for which the local causal effects
+                       needs to be generated for a given point.
+        :type X_test: Any
+        :return: An object of type CausalData with
+                 causal effects for a given point.
+        :rtype: CausalData
+        """
+        filtered = [r for r in self.get() if r.id == id]
+
+        if len(filtered) == 0:
+            raise ValueError(f"Failed to find causal result with ID: {id}")
+
+        if not isinstance(X_test, pd.DataFrame):
+            raise UserConfigValidationException(
+                'Data is of type {0} but it must be '
+                'a pandas DataFrame.'.format(type(X_test)))
+
+        if X_test.shape[0] > 1:
+            raise UserConfigValidationException(
+                'Only one row of data is allowed for '
+                'local causal effects.')
+
+        result = filtered[0]
+        return result._local_instance_effects(X_test)
+
+    def request_global_cohort_policy(self, id, X_test):
+        """Get global causal policy for cohort data.
+
+        :param id: The query id for finding the
+                   causal config.
+        :type id: str
+        :param X_test: The data for which the causal policy
+                       needs to be generated.
+        :type X_test: Any
+        :return: An object of type CausalData with
+                 causal effects.
+        :rtype: CausalData
+        """
+        filtered = [r for r in self.get() if r.id == id]
+        if len(filtered) == 0:
+            raise ValueError(f"Failed to find causal result with ID: {id}")
+        result = filtered[0]
+        return result._global_cohort_policy(X_test)
+
     def compute(self):
         """Computes the causal effects by running the causal
            configuration."""
@@ -339,7 +393,7 @@ class CausalManager(BaseManager):
 
                 for i in range(len(causal_config.treatment_features)):
                     policy = self._create_policy(
-                        analysis, X_test,
+                        result, X_test,
                         causal_config.treatment_features[i],
                         revised_treatment_cost[i],
                         causal_config.alpha, causal_config.max_tree_depth,
