@@ -12,11 +12,14 @@ from typing import Any, List, Optional
 import numpy as np
 import pandas as pd
 
+from erroranalysis._internal.cohort_filter import FilterDataWithCohortFilters
+from erroranalysis._internal.process_categoricals import process_categoricals
 from raiutils.data_processing import convert_to_list
 from raiutils.models import SKLearn, is_classifier
 from responsibleai._interfaces import Dataset, RAIInsightsData
 from responsibleai._internal.constants import ManagerNames, Metadata
 from responsibleai.exceptions import UserConfigValidationException
+from responsibleai.feature_metadata import FeatureMetadata
 from responsibleai.managers.causal_manager import CausalManager
 from responsibleai.managers.counterfactual_manager import CounterfactualManager
 from responsibleai.managers.data_balance_manager import DataBalanceManager
@@ -27,12 +30,18 @@ from responsibleai.rai_insights.rai_base_insights import RAIBaseInsights
 
 _PREDICTIONS = 'predictions'
 _TRAIN = 'train'
+_TEST = 'test'
 _TARGET_COLUMN = 'target_column'
 _TASK_TYPE = 'task_type'
 _CLASSES = 'classes'
 _FEATURE_COLUMNS = 'feature_columns'
+_FEATURE_METADATA = 'feature_metadata'
 _FEATURE_RANGES = 'feature_ranges'
 _CATEGORICAL_FEATURES = 'categorical_features'
+_CATEGORIES = 'categories'
+_CATEGORY_DICTIONARY = 'category_dictionary'
+_CATEGORICAL_INDEXES = 'categorical_indexes'
+_STRING_IND_DATA = 'string_ind_data'
 _META_JSON = Metadata.META_JSON
 _TRAIN_LABELS = 'train_labels'
 _JSON_EXTENSION = '.json'
@@ -57,7 +66,8 @@ class RAIInsights(RAIBaseInsights):
                  categorical_features: Optional[List[str]] = None,
                  classes: Optional[np.ndarray] = None,
                  serializer: Optional[Any] = None,
-                 maximum_rows_for_test: int = 5000):
+                 maximum_rows_for_test: int = 5000,
+                 feature_metadata: Optional[FeatureMetadata] = None):
         """Creates an RAIInsights object.
         :param model: The model to compute RAI insights for.
             A model that implements sklearn.predict or sklearn.predict_proba
@@ -85,6 +95,10 @@ class RAIInsights(RAIBaseInsights):
         :param maximum_rows_for_test: Limit on size of test data
             (for performance reasons)
         :type maximum_rows_for_test: int
+        :param feature_metadata: Feature metadata for the train/test
+                                 dataset to identify different kinds
+                                 of features in the dataset.
+        :type feature_metadata: FeatureMetadata
         """
         categorical_features = categorical_features or []
         self._validate_rai_insights_input_parameters(
@@ -93,7 +107,8 @@ class RAIInsights(RAIBaseInsights):
             categorical_features=categorical_features,
             classes=classes,
             serializer=serializer,
-            maximum_rows_for_test=maximum_rows_for_test)
+            maximum_rows_for_test=maximum_rows_for_test,
+            feature_metadata=feature_metadata)
         self._classes = RAIInsights._get_classes(
             task_type=task_type,
             train=train,
@@ -105,7 +120,15 @@ class RAIInsights(RAIBaseInsights):
         self._feature_ranges = RAIInsights._get_feature_ranges(
             test=test, categorical_features=categorical_features,
             feature_columns=self._feature_columns)
+        self._feature_metadata = feature_metadata
+
         self.categorical_features = categorical_features
+        self._categories, self._categorical_indexes, \
+            self._category_dictionary, self._string_ind_data = \
+            process_categoricals(
+                all_feature_names=self._feature_columns,
+                categorical_features=self.categorical_features,
+                dataset=test.drop(columns=[target_column]))
 
         super(RAIInsights, self).__init__(
             model, train, test, target_column, task_type,
@@ -178,7 +201,8 @@ class RAIInsights(RAIBaseInsights):
             target_column: str, task_type: str,
             categorical_features: List[str], classes: np.ndarray,
             serializer,
-            maximum_rows_for_test: int):
+            maximum_rows_for_test: int,
+            feature_metadata: Optional[FeatureMetadata] = None):
         """Validate the inputs for the RAIInsights constructor.
 
         :param model: The model to compute RAI insights for.
@@ -206,6 +230,10 @@ class RAIInsights(RAIBaseInsights):
         :param maximum_rows_for_test: Limit on size of test data
             (for performance reasons)
         :type maximum_rows_for_test: int
+        :param feature_metadata: Feature metadata for the train/test
+                                 dataset to identify different kinds
+                                 of features in the dataset.
+        :type feature_metadata: FeatureMetadata
         """
 
         valid_tasks = [
@@ -364,6 +392,15 @@ class RAIInsights(RAIBaseInsights):
                 "Expecting pandas DataFrame for train and test."
             )
 
+        if feature_metadata is not None:
+            if not isinstance(feature_metadata, FeatureMetadata):
+                raise UserConfigValidationException(
+                    "Expecting type FeatureMetadata but got {0}".format(
+                        type(feature_metadata)))
+
+            feature_metadata.validate_feature_metadata_with_user_features(
+                list(train.columns))
+
     def _validate_features_same(self, small_train_features_before,
                                 small_train_data, function):
         """
@@ -417,6 +454,37 @@ class RAIInsights(RAIBaseInsights):
         """
         return self._explainer_manager
 
+    def get_filtered_test_data(self, filters, composite_filters,
+                               include_original_columns_only=False):
+        """Get the filtered test data based on cohort filters.
+
+        :param filters: The filters to apply.
+        :type filters: list[Filter]
+        :param composite_filters: The composite filters to apply.
+        :type composite_filters: list[CompositeFilter]
+        :param include_original_columns_only: Whether to return the original
+                                              data columns.
+        :type include_original_columns_only: bool
+        :return: The filtered test data.
+        :rtype: pandas.DataFrame
+        """
+        pred_y = self.model.predict(
+            self.test.drop(columns=[self.target_column]))
+        filter_data_with_cohort = FilterDataWithCohortFilters(
+            model=self.model,
+            dataset=self.test.drop(columns=[self.target_column]),
+            features=self.test.drop(columns=[self.target_column]).columns,
+            categorical_features=self.categorical_features,
+            categories=self._categories,
+            true_y=self.test[self.target_column],
+            pred_y=pred_y,
+            model_task=self.task_type)
+
+        return filter_data_with_cohort.filter_data_from_cohort(
+            filters=filters,
+            composite_filters=composite_filters,
+            include_original_columns_only=include_original_columns_only)
+
     def get_data(self):
         """Get all data as RAIInsightsData object
 
@@ -437,6 +505,13 @@ class RAIInsights(RAIBaseInsights):
         dashboard_dataset.categorical_features = self.categorical_features
         dashboard_dataset.class_names = convert_to_list(
             self._classes)
+
+        if self._feature_metadata is not None:
+            dashboard_dataset.feature_metadata = \
+                self._feature_metadata.to_dict()
+        else:
+            dashboard_dataset.feature_metadata = None
+
         dashboard_dataset.data_balance_measures = \
             self._data_balance_manager.get_data()
 
@@ -557,14 +632,17 @@ class RAIInsights(RAIBaseInsights):
         """
         top_dir = Path(path)
         classes = convert_to_list(self._classes)
+        feature_metadata_dict = None
+        if self._feature_metadata is not None:
+            feature_metadata_dict = self._feature_metadata.to_dict()
         meta = {
             _TARGET_COLUMN: self.target_column,
             _TASK_TYPE: self.task_type,
             _CATEGORICAL_FEATURES: self.categorical_features,
             _CLASSES: classes,
             _FEATURE_COLUMNS: self._feature_columns,
-            _FEATURE_RANGES: self._feature_ranges
-
+            _FEATURE_RANGES: self._feature_ranges,
+            _FEATURE_METADATA: feature_metadata_dict
         }
         with open(top_dir / _META_JSON, 'w') as file:
             json.dump(meta, file)
@@ -622,6 +700,28 @@ class RAIInsights(RAIBaseInsights):
 
         inst.__dict__['_' + _FEATURE_COLUMNS] = meta[_FEATURE_COLUMNS]
         inst.__dict__['_' + _FEATURE_RANGES] = meta[_FEATURE_RANGES]
+        if meta[_FEATURE_METADATA] is None:
+            inst.__dict__['_' + _FEATURE_METADATA] = None
+        else:
+            inst.__dict__['_' + _FEATURE_METADATA] = FeatureMetadata(
+                identity_feature_name=meta[_FEATURE_METADATA][
+                    'identity_feature_name'],
+                datetime_features=meta[_FEATURE_METADATA][
+                    'datetime_features'],
+                categorical_features=meta[_FEATURE_METADATA][
+                    'categorical_features'],
+                dropped_features=meta[_FEATURE_METADATA][
+                    'dropped_features'],)
+
+        inst.__dict__['_' + _CATEGORIES], \
+            inst.__dict__['_' + _CATEGORICAL_INDEXES], \
+            inst.__dict__['_' + _CATEGORY_DICTIONARY], \
+            inst.__dict__['_' + _STRING_IND_DATA] = \
+            process_categoricals(
+                all_feature_names=inst.__dict__['_' + _FEATURE_COLUMNS],
+                categorical_features=inst.__dict__[_CATEGORICAL_FEATURES],
+                dataset=inst.__dict__[_TEST].drop(columns=[
+                    inst.__dict__[_TARGET_COLUMN]]))
 
     @staticmethod
     def load(path):
