@@ -7,6 +7,7 @@ import numpy as np
 import pytest
 
 from responsibleai import ModelTask, RAIInsights
+from responsibleai._interfaces import CausalData
 from responsibleai._tools.shared.state_directory_management import \
     DirectoryManager
 from responsibleai.exceptions import UserConfigValidationException
@@ -106,6 +107,126 @@ class TestCausalManager:
                         skip_cat_limit_checks=True,
                         upper_bound_on_cat_expansion=50)
 
+    def verify_common_causal_data_attributes(self, causal_data):
+        assert isinstance(causal_data, CausalData)
+        assert hasattr(causal_data, 'id')
+        assert hasattr(causal_data, 'version')
+        assert hasattr(causal_data, 'config')
+
+    def test_causal_manager_global_cohort_effects(self, housing_data):
+        train_df, test_df, target_feature = housing_data
+
+        manager = CausalManager(train_df, test_df, target_feature,
+                                ModelTask.REGRESSION, None)
+        manager.add(['AveRooms'])
+        manager.compute()
+
+        id = manager.get()[0].id
+        X_test = test_df.drop(target_feature, axis=1)
+        causal_data = manager.request_global_cohort_effects(id, X_test)
+
+        self.verify_common_causal_data_attributes(causal_data)
+        assert hasattr(causal_data, 'global_effects')
+        EFFECTS_ATTRIBUTES = [
+            'point',
+            'stderr',
+            'zstat',
+            'ci_lower',
+            'ci_upper',
+            'p_value',
+        ]
+        for effect in EFFECTS_ATTRIBUTES:
+            assert effect in causal_data.global_effects[0]
+
+        incorrect_query_id = "incorrect_query_id"
+        X_test = test_df.drop(target_feature, axis=1)
+        with pytest.raises(
+                ValueError,
+                match="Failed to find causal result with ID: "
+                      "incorrect_query_id"):
+            manager.request_global_cohort_effects(
+                incorrect_query_id, X_test)
+
+    def test_causal_manager_global_cohort_policy(self, housing_data):
+        train_df, test_df, target_feature = housing_data
+
+        manager = CausalManager(train_df, test_df, target_feature,
+                                ModelTask.REGRESSION, None)
+        manager.add(['AveRooms'])
+        manager.compute()
+
+        id = manager.get()[0].id
+        X_test = test_df.head(5).drop(target_feature, axis=1)
+        causal_data = manager.request_global_cohort_policy(id, X_test)
+
+        self.verify_common_causal_data_attributes(causal_data)
+        assert hasattr(causal_data, 'policies')
+        assert len(causal_data.policies[0].local_policies) == X_test.shape[0]
+        assert causal_data.policies[0].treatment_feature == "AveRooms"
+
+        incorrect_query_id = "incorrect_query_id"
+        X_test = test_df.drop(target_feature, axis=1)
+        with pytest.raises(
+                ValueError,
+                match="Failed to find causal result with ID: "
+                      "incorrect_query_id"):
+            manager.request_global_cohort_effects(
+                incorrect_query_id, X_test)
+
+    def test_causal_manager_local_instance_effects(self, housing_data):
+        train_df, test_df, target_feature = housing_data
+
+        manager = CausalManager(train_df, test_df, target_feature,
+                                ModelTask.REGRESSION, None)
+        manager.add(['AveRooms'])
+        manager.compute()
+
+        id = manager.get()[0].id
+        X_test = test_df.head(1).drop(target_feature, axis=1)
+        causal_data = manager.request_local_instance_effects(id, X_test)
+
+        self.verify_common_causal_data_attributes(causal_data)
+        assert hasattr(causal_data, 'local_effects')
+        EFFECTS_ATTRIBUTES = [
+            'sample',
+            'outcome',
+            'feature',
+            'feature_value',
+            'point',
+            'stderr',
+            'zstat',
+            'ci_lower',
+            'ci_upper',
+            'p_value',
+        ]
+        for effect in EFFECTS_ATTRIBUTES:
+            assert effect in causal_data.local_effects[0][0]
+
+        incorrect_query_id = "incorrect_query_id"
+        X_test = test_df.drop(target_feature, axis=1)
+        with pytest.raises(
+                ValueError,
+                match="Failed to find causal result with ID: "
+                      "incorrect_query_id"):
+            manager.request_local_instance_effects(
+                incorrect_query_id, X_test)
+
+        id = manager.get()[0].id
+        X_test = test_df.head(1).drop(target_feature, axis=1).values
+        with pytest.raises(
+                UserConfigValidationException,
+                match='Data is of type <class \'numpy.ndarray\'>'
+                      ' but it must be a pandas DataFrame.'):
+            manager.request_local_instance_effects(id, X_test)
+
+        id = manager.get()[0].id
+        X_test = test_df.head(5).drop(target_feature, axis=1)
+        with pytest.raises(
+                UserConfigValidationException,
+                match='Only one row of data is allowed for '
+                      'local causal effects.'):
+            manager.request_local_instance_effects(id, X_test)
+
 
 @pytest.fixture(scope='class')
 def cost_manager(housing_data):
