@@ -10,25 +10,25 @@ from uuid import UUID
 import numpy as np
 import pandas as pd
 import pytest
+from tests.causal_manager_validator import validate_causal
+from tests.common_utils import (create_adult_income_dataset,
+                                create_binary_classification_dataset,
+                                create_cancer_data,
+                                create_complex_classification_pipeline,
+                                create_housing_data, create_iris_data,
+                                create_models_classification,
+                                create_models_regression)
+from tests.counterfactual_manager_validator import validate_counterfactual
+from tests.error_analysis_validator import (setup_error_analysis,
+                                            validate_error_analysis)
+from tests.explainer_manager_validator import (setup_explainer,
+                                               validate_explainer)
 
 from responsibleai import ModelTask, RAIInsights
 from responsibleai._internal.constants import ManagerNames
 from responsibleai._tools.shared.state_directory_management import \
     DirectoryManager
 
-from .causal_manager_validator import validate_causal
-from .common_utils import (create_adult_income_dataset,
-                           create_binary_classification_dataset,
-                           create_cancer_data,
-                           create_complex_classification_pipeline,
-                           create_housing_data, create_iris_data,
-                           create_models_classification,
-                           create_models_regression)
-from .counterfactual_manager_validator import validate_counterfactual
-from .error_analysis_validator import (setup_error_analysis,
-                                       validate_error_analysis)
-from .explainer_manager_validator import setup_explainer, validate_explainer
-
 LABELS = 'labels'
 
 
@@ -342,6 +342,16 @@ def validate_rai_insights(
     assert rai_insights.target_column == target_column
     assert rai_insights.task_type == task_type
     assert rai_insights.categorical_features == (categorical_features or [])
+    expected_length = 0
+    if categorical_features is not None:
+        expected_length = len(categorical_features)
+    assert len(rai_insights.categorical_features) == expected_length
+    assert len(rai_insights._categories) == expected_length
+    assert len(rai_insights._categorical_indexes) == expected_length
+    assert len(rai_insights._category_dictionary) == expected_length
+    for ind_data in rai_insights._string_ind_data:
+        assert len(ind_data) == expected_length
+
     if task_type == ModelTask.CLASSIFICATION:
         classes = train_data[target_column].unique()
         classes.sort()
